package org.eco.als.service.impl;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONUtil;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.AlgorithmBo;
import org.eco.als.domain.vo.DataImportVo;
import org.eco.als.domain.vo.ModelHttpVo;
import org.eco.als.domain.vo.ModelVo;
import org.eco.als.service.IAlgorithmService;
import org.eco.als.service.IDataImportService;
import org.eco.als.service.IModelService;
import org.eco.common.core.exception.BusinessException;
import org.eco.common.core.utils.HttpUtils;
import org.eco.system.service.ISysOssService;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;

/**
 * @Description: AlgorithmService
 * @Author: GaoKun Wang
 * @Date: 2024/7/30
 */
@Service
@Slf4j
public class AlgorithmService implements IAlgorithmService {
    @Resource
    private IModelService modelService;

    @Resource
    private IDataImportService dataImportService;

    @Resource
    private ISysOssService ossService;

    /**
     * executePro 预处理
     *
     * @param algorithmBo 参数
     * @return java.lang.String
     **/
    @Override
    public String executePro(AlgorithmBo algorithmBo) {
        // 模型相关信息
        ModelVo modelVo = modelService.selectById(algorithmBo.getModelId());
        if (ObjectUtil.isNull(modelVo)) {
            throw new BusinessException("模型信息为空，请检查！");
        }
        // 数据相关信息
        DataImportVo dataVo = dataImportService.selectById(algorithmBo.getDataId());
        if (ObjectUtil.isNull(dataVo)) {
            throw new BusinessException("数据为空，请检查！");
        }
        // 参数
        String param = algorithmBo.getParam();
        Map<String, Object> map = new HashMap<>(JSONUtil.parseObj(param));
        map.put("url", modelVo.getUrl());

        // 数据url


        // 请求
        ModelHttpVo result = HttpUtils.postJson(modelVo.getUrl(), map, ModelHttpVo.class);


        String url = modelVo.getUrl();

        return null;
    }

    public static void main(String[] args) {
        String jsonStr = "{\"name\":\"John\", \"age\":30, \"city\":\"New York\"}";
        Map<String, Object> map = new HashMap<>(JSONUtil.parseObj(jsonStr));
        System.out.println(map);

    }
}
